pub trait HostPollable: Send {
// Required methods
fn ready(
&mut self,
self_: Resource<Pollable>,
) -> impl Future<Output = Result<bool>> + Send;
fn block(
&mut self,
self_: Resource<Pollable>,
) -> impl Future<Output = Result<()>> + Send;
fn drop(
&mut self,
rep: Resource<Pollable>,
) -> impl Future<Output = Result<()>> + Send;
}Required Methods
Sourcefn ready(
&mut self,
self_: Resource<Pollable>,
) -> impl Future<Output = Result<bool>> + Send
fn ready( &mut self, self_: Resource<Pollable>, ) -> impl Future<Output = Result<bool>> + Send
Return the readiness of a pollable. This function never blocks.
Returns true when the pollable is ready, and false otherwise.
Sourcefn block(
&mut self,
self_: Resource<Pollable>,
) -> impl Future<Output = Result<()>> + Send
fn block( &mut self, self_: Resource<Pollable>, ) -> impl Future<Output = Result<()>> + Send
block returns immediately if the pollable is ready, and otherwise
blocks until ready.
This function is equivalent to calling poll.poll on a list
containing only this pollable.
fn drop( &mut self, rep: Resource<Pollable>, ) -> impl Future<Output = Result<()>> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<_T: HostPollable + ?Sized + Send> HostPollable for &mut _T
impl<_T: HostPollable + ?Sized + Send> HostPollable for &mut _T
Sourcefn ready(
&mut self,
self_: Resource<Pollable>,
) -> impl Future<Output = Result<bool>> + Send
fn ready( &mut self, self_: Resource<Pollable>, ) -> impl Future<Output = Result<bool>> + Send
Return the readiness of a pollable. This function never blocks.
Returns true when the pollable is ready, and false otherwise.
Sourcefn block(
&mut self,
self_: Resource<Pollable>,
) -> impl Future<Output = Result<()>> + Send
fn block( &mut self, self_: Resource<Pollable>, ) -> impl Future<Output = Result<()>> + Send
block returns immediately if the pollable is ready, and otherwise
blocks until ready.
This function is equivalent to calling poll.poll on a list
containing only this pollable.